pointr: Package 'pointr'

Description

Description

The pointr package allows to work with pointers to R objects/selection in order to make the R code more readable and maintainable. The main function of the package are: ptr() to create a pointer, rm.ptr() to remove a pointer, and where.ptr() to check the target object of a pointer.


jsugarelli/pointr documentation built on Jan. 1, 2021, 3 p.m.