The pointr package allows to work with pointers to R
objects/selection in order to make the R code more readable and
maintainable.
The main function of the package are: ptr() to
create a pointer, rm.ptr() to remove a pointer, and
where.ptr() to check the target object of a pointer.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.